pub struct MilestoneInfo {
pub milestone_id: Option<MilestoneId>,
pub milestone_index: u32,
pub milestone_timestamp: u32,
}Fields
milestone_id: Option<MilestoneId>Optional. This field can be missing for example if there are no milestones yet in a network.
milestone_index: u32milestone_timestamp: u32Optional. This field can be missing for example if there are no milestones yet in a network.